==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/space/messages/ru/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Это сообщество по прежнему пусто!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Это сообщество ещё пусто!</b><br>Начните активность в нём, разместив что-нибудь здесь...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Вы не участник данного сообщества, а общедоступного контента пока нет!</b>',
    '<strong>About</strong> the Space' => '<strong>Информация</strong>',
    '<strong>About</strong> your membership' => '<strong>О</strong> вашем участии',
    '<strong>Confirm</strong> image deletion' => '<strong>Подтвердите</strong> удаление изображения',
    '<strong>Invite</strong> members' => '<strong>Пригласить</strong> пользователей',
    '<strong>Leave</strong> Space' => '<strong>Покинуть</strong> сообщество',
    '<strong>New</strong> member request' => '<strong>Новые</strong> запросы на вступление',
    '<strong>New</strong> spaces' => '<strong>Новые</strong> сообщества',
    '<strong>Request</strong> Membership' => '<strong>Отправить</strong> запрос на вступление',
    '<strong>Space</strong> followers' => '<strong>Подписчики</strong> сообщества',
    '<strong>Space</strong> members' => '<strong>Участники</strong> сообщества',
    '<strong>Space</strong> menu' => '<strong>Меню</strong> сообщества',
    '<strong>Space</strong> tags' => 'Теги <strong>Сообщество</strong>',
    '<strong>Spaces</strong>' => '<strong>Сообщества</strong>',
    'About' => 'Информация',
    'Accept' => 'Активировать',
    'Accept Invite' => 'Принять приглашение',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Пожалуйста, представьтесь, чтобы стать участником сообщества.',
    'Add users without invitation' => 'Добавить пользователей без приглашения',
    'Admin' => 'Администратор',
    'Administrator:' => 'Администратор:',
    'Administrators' => 'Администраторы',
    'Any' => 'Любой',
    'Archived' => 'В архиве',
    'As owner you cannot revoke your membership!' => 'Как владелец, Вы не можете покинуть это сообщество!',
    'Blocked users' => 'Заблокированные пользователи',
    'By Name' => 'По имени',
    'Cancel' => 'Отменить',
    'Change visibility' => 'Изменить видимость',
    'Close' => 'Закрыть',
    'Color' => 'Цвет',
    'Could not request membership!' => 'Не удалось выполнить запрос на вступление в сообщество!',
    'Create new link' => 'Создать новую ссылку',
    'Created At' => 'Создано в',
    'Created By' => 'Создано',
    'Decline' => 'Отказать',
    'Decline Invite' => 'Отменить приглашение',
    'Default' => 'По умолчанию',
    'Default content visibility' => 'Видимость контента по умолчанию',
    'Delete' => 'Удалить',
    'Description' => 'Описание',
    'Do you really want to delete your profile image?' => 'Вы действительно хотите удалить изображение профиля?',
    'Do you really want to delete your title image?' => 'Вы действительно хотите удалить изображение обложки?',
    'Done' => 'Выполнено',
    'Email addresses' => 'Адреса электронной почты',
    'Everyone can enter' => 'Каждый может вступить',
    'Find Spaces by their description or by their tags' => 'Находите пространства по описанию или по тегам',
    'Follow' => 'Подписаться',
    'Followers' => 'Подписчиков',
    'Following' => 'Подписан(а)',
    'Guests' => 'Гости',
    'Hide About Page' => 'Скрыть страницу «О программе»',
    'Hide Activity Sidebar Widget' => 'Скрыть виджет боковой панели активности',
    'Hide Followers' => 'Скрыть подписчиков',
    'Hide Members' => 'Скрыть участников',
    'Homepage' => 'Главная страница',
    'Homepage (Non-members)' => 'Домашняя страница (не участники)',
    'I want to become a member because...' => 'Я хочу стать участником, потому что...',
    'Incorrect name, try again.' => 'Неправильное название, попробуйте еще раз.',
    'Invite' => 'Пригласить',
    'Invite and request' => 'Приглашение и запрос',
    'Invite by email' => 'Пригласить с помощью электронной почты',
    'Invite by link' => 'Пригласить по ссылке',
    'Invite link' => 'Ссылка для приглашения',
    'Invites' => 'Приглашения',
    'Join' => 'Присоединиться',
    'Join Policy' => 'Регистрационная политика',
    'Last Visit' => 'Последний визит',
    'Leave' => 'Покинуть',
    'Login' => 'Войти',
    'Max. 100 characters.' => 'Макс. 100 символов.',
    'Member' => 'Участник',
    'Member since' => 'Участник с',
    'Members' => 'Участники',
    'Moderator' => 'Модератор',
    'Moderator:' => 'Модератор:',
    'Moderators' => 'Модераторы',
    'My Space List' => 'Мои сообщества',
    'My space summary' => 'Сводка сообществ',
    'Name' => 'Название',
    'Name / Sort order' => 'Название / Порядок сортировки',
    'Neither..nor' => 'Не один из',
    'New user by e-mail (comma separated)' => 'Адреса электронной почты новых пользователей (через запятую)',
    'New user?' => 'Новый пользователь?',
    'Newest first' => 'Сначала самые новые',
    'No results found!' => 'Результатов не найдено!',
    'No spaces found.' => 'Сообщества не найдены.',
    'Oldest first' => 'Сначала самый старый',
    'Only by invite' => 'Только по приглашению',
    'Originator User ID' => 'Первоисточник User ID',
    'Owner' => 'Владелец',
    'Owner:' => 'Владелец:',
    'Pending' => 'В ожидании',
    'Pick users' => 'Зарегистрированные пользователи',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Обратите внимание, что любые ранее созданные вами ссылки станут недействительными, как только вы создадите новую. Хотите продолжить?',
    'Posts' => 'Записей',
    'Private' => 'Закрытые сообщества',
    'Private (Invisible)' => 'Закрытое сообщество (скрытое ото всех, кроме его участников)',
    'Public' => 'Открытые сообщества',
    'Public (Members & Guests)' => 'Публичное (Участники и Гости)',
    'Public (Members only)' => 'Публичное (только Участники)',
    'Public (Registered users only)' => 'Видимо для Пользователей (только для зарегистрированных)',
    'Request Message' => 'Запрашиваемое сообщение',
    'Role' => 'Роль',
    'Search...' => 'Поиск...',
    'See all' => 'Посмотреть все',
    'Select all registered users' => 'Выбрать всех зарегистрированных пользователей',
    'Send' => 'Отправить',
    'Send the link via email' => 'Отправьте ссылку по электронной почте',
    'Settings' => 'Настройки',
    'Settings could not be saved!' => 'Настройки не удалось сохранить!',
    'Show all' => 'Показать всех',
    'Show as List' => 'Показать как список',
    'Shown on About Page.' => 'Отображается на странице «Информация».',
    'Sorry, you are not allowed to leave this space!' => 'Извините, Вам не разрешено покинуть это сообщество',
    'Sorting' => 'Сортировка',
    'Space' => 'Сообщество',
    'Space Name' => 'Название сообщества',
    'Space Visibility' => 'Видимость сообщества',
    'Space directory' => 'Директория сообщества',
    'Space is invisible!' => 'Сообщество скрыто!',
    'Spaces' => 'Сообщества',
    'Status' => 'Статус',
    'Stream' => 'Активность',
    'Tags' => 'Теги',
    'The default homepage for members of this Space' => 'Домашняя страница по умолчанию для участников этого сообщества.',
    'The default homepage for non-members and guests visiting this Space' => 'Домашняя страница по умолчанию для лиц, не являющихся участниками, и гостей, посещающих это сообщество.',
    'The secure link has been copied in your clipboard!' => 'Защищенная ссылка скопирована в буфер обмена!',
    'There is no pending invite!' => 'Нет ожидающих приглашений!',
    'This action is only available for workspace members!' => 'Это действие доступно только для участников этого сообщества!',
    'This user is already a member of this space.' => 'Этот пользователь уже является участником этого сообщества.',
    'This user is not a member of this space.' => 'Этот пользователь не является участником этого сообщества.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Чтобы пригласить пользователей в это сообщество, введите их имена ниже, чтобы найти и выбрать их.',
    'Try other keywords or remove filters.' => 'Попробуйте другие ключевые слова или удалите фильтры.',
    'Updated At' => 'Обновлено в',
    'Updated By' => 'Обновлено',
    'Updated by' => 'Обновлено',
    'User \'{username}\' is already a member of this space!' => 'Пользователь \'{username}\' уже является участником этого сообщества!',
    'User invitations have been added to the queue' => 'Приглашения на вступления для пользователей добавлены',
    'User memberships have been added to the queue' => 'Пользователи приглашены для вступления',
    'User not found!' => 'Пользователь не найден!',
    'Users' => 'Пользователи',
    'Users has been invited.' => 'Пользователи были приглашены.',
    'Visibility' => 'Видимость сообщества',
    'Visible for all (members and guests)' => 'Видимо для всех (для Участников и Гостей)',
    'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => 'Предупреждение. Если вы измените настройки видимости сообщества с общедоступного на частное, весь контент в этом сообществе, включая публикации, комментарии, вложения и т. д., также станет частным. Это означает, что лица, не являющиеся участниками, больше не смогут видеть, получать доступ или взаимодействовать с каким-либо контентом в этом Сообществе.',
    'Would you like to end your membership in Space {spaceName}?' => 'Хотите прекратить свое членство в Сообществе {spaceName}?',
    'Would you like to unfollow Space {spaceName}?' => 'Хотите отписаться от Сообщества {spaceName}?',
    'Would you like to unfollow {userName}?' => 'Хотите отписаться от пользователя {userName}?',
    'Would you like to withdraw your request to join Space {spaceName}?' => 'Хотите отозвать свой запрос на вступление в Сообщество {spaceName}?',
    'You are not allowed to join this space!' => 'Вы не можете присоединиться к этому сообществу!',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Вы также можете пригласить по электронной почте внешних пользователей, которые сейчас не зарегистрированы. Просто добавьте их адреса электронной почты через запятую.',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'Вы можете пригласить внешних пользователей, которые в данный момент не зарегистрированы, по ссылке. Все, что вам нужно сделать, это поделиться с ними этой безопасной ссылкой.',
    'You cannot create private visible spaces!' => 'Вы не можете создавать закрытые сообщества!',
    'You cannot create public visible spaces!' => 'Вы не можете создавать открытые (публичные) сообщества!',
    'You need to login to view contents of this space!' => 'Вы должны войти/зарегистрироваться, чтобы просматривать содержимое этого сообщества!',
    'Your Message' => 'Сообщение',
    'Your request was successfully submitted to the space administrators.' => 'Ваша заявка на вступление была успешно отправлена администратору сообщества.',
    '{count} members' => '{count} участников',
    '{email} is not valid!' => '{email} некорректный!',
    'Advanced Spaces Search' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/space/messages/ru/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Это сообщество по прежнему пусто!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Это сообщество ещё пусто!</b><br>Начните активность в нём, разместив что-нибудь здесь...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Вы не участник данного сообщества, а общедоступного контента пока нет!</b>',
    '<strong>About</strong> the Space' => '<strong>Информация</strong>',
    '<strong>About</strong> your membership' => '<strong>О</strong> вашем участии',
    '<strong>Confirm</strong> image deletion' => '<strong>Подтвердите</strong> удаление изображения',
    '<strong>Invite</strong> members' => '<strong>Пригласить</strong> пользователей',
    '<strong>Leave</strong> Space' => '<strong>Покинуть</strong> сообщество',
    '<strong>New</strong> member request' => '<strong>Новые</strong> запросы на вступление',
    '<strong>New</strong> spaces' => '<strong>Новые</strong> сообщества',
    '<strong>Request</strong> Membership' => '<strong>Отправить</strong> запрос на вступление',
    '<strong>Space</strong> followers' => '<strong>Подписчики</strong> сообщества',
    '<strong>Space</strong> members' => '<strong>Участники</strong> сообщества',
    '<strong>Space</strong> menu' => '<strong>Меню</strong> сообщества',
    '<strong>Space</strong> tags' => 'Теги <strong>Сообщество</strong>',
    '<strong>Spaces</strong>' => '<strong>Сообщества</strong>',
    'About' => 'Информация',
    'Accept' => 'Активировать',
    'Accept Invite' => 'Принять приглашение',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Пожалуйста, представьтесь, чтобы стать участником сообщества.',
    'Add users without invitation' => 'Добавить пользователей без приглашения',
    'Admin' => 'Администратор',
    'Administrator:' => 'Администратор:',
    'Administrators' => 'Администраторы',
    'Advanced Spaces Search' => 'Расширенный поиск в сообществах',
    'Any' => 'Любой',
    'Archived' => 'В архиве',
    'As owner you cannot revoke your membership!' => 'Как владелец, Вы не можете покинуть это сообщество!',
    'Blocked users' => 'Заблокированные пользователи',
    'By Name' => 'По имени',
    'Cancel' => 'Отменить',
    'Change visibility' => 'Изменить видимость',
    'Close' => 'Закрыть',
    'Color' => 'Цвет',
    'Could not request membership!' => 'Не удалось выполнить запрос на вступление в сообщество!',
    'Create new link' => 'Создать новую ссылку',
    'Created At' => 'Создано в',
    'Created By' => 'Создано',
    'Decline' => 'Отказать',
    'Decline Invite' => 'Отменить приглашение',
    'Default' => 'По умолчанию',
    'Default content visibility' => 'Видимость контента по умолчанию',
    'Delete' => 'Удалить',
    'Description' => 'Описание',
    'Do you really want to delete your profile image?' => 'Вы действительно хотите удалить изображение профиля?',
    'Do you really want to delete your title image?' => 'Вы действительно хотите удалить изображение обложки?',
    'Done' => 'Выполнено',
    'Email addresses' => 'Адреса электронной почты',
    'Everyone can enter' => 'Каждый может вступить',
    'Find Spaces by their description or by their tags' => 'Находите пространства по описанию или по тегам',
    'Follow' => 'Подписаться',
    'Followers' => 'Подписчиков',
    'Following' => 'Подписан(а)',
    'Guests' => 'Гости',
    'Hide About Page' => 'Скрыть страницу «О программе»',
    'Hide Activity Sidebar Widget' => 'Скрыть виджет боковой панели активности',
    'Hide Followers' => 'Скрыть подписчиков',
    'Hide Members' => 'Скрыть участников',
    'Homepage' => 'Главная страница',
    'Homepage (Non-members)' => 'Домашняя страница (не участники)',
    'I want to become a member because...' => 'Я хочу стать участником, потому что...',
    'Incorrect name, try again.' => 'Неправильное название, попробуйте еще раз.',
    'Invite' => 'Пригласить',
    'Invite and request' => 'Приглашение и запрос',
    'Invite by email' => 'Пригласить с помощью электронной почты',
    'Invite by link' => 'Пригласить по ссылке',
    'Invite link' => 'Ссылка для приглашения',
    'Invites' => 'Приглашения',
    'Join' => 'Присоединиться',
    'Join Policy' => 'Регистрационная политика',
    'Last Visit' => 'Последний визит',
    'Leave' => 'Покинуть',
    'Login' => 'Войти',
    'Max. 100 characters.' => 'Макс. 100 символов.',
    'Member' => 'Участник',
    'Member since' => 'Участник с',
    'Members' => 'Участники',
    'Moderator' => 'Модератор',
    'Moderator:' => 'Модератор:',
    'Moderators' => 'Модераторы',
    'My Space List' => 'Мои сообщества',
    'My space summary' => 'Сводка сообществ',
    'Name' => 'Название',
    'Name / Sort order' => 'Название / Порядок сортировки',
    'Neither..nor' => 'Не один из',
    'New user by e-mail (comma separated)' => 'Адреса электронной почты новых пользователей (через запятую)',
    'New user?' => 'Новый пользователь?',
    'Newest first' => 'Сначала самые новые',
    'No results found!' => 'Результатов не найдено!',
    'No spaces found.' => 'Сообщества не найдены.',
    'Oldest first' => 'Сначала самый старый',
    'Only by invite' => 'Только по приглашению',
    'Originator User ID' => 'Первоисточник User ID',
    'Owner' => 'Владелец',
    'Owner:' => 'Владелец:',
    'Pending' => 'В ожидании',
    'Pick users' => 'Зарегистрированные пользователи',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Обратите внимание, что любые ранее созданные вами ссылки станут недействительными, как только вы создадите новую. Хотите продолжить?',
    'Posts' => 'Записей',
    'Private' => 'Закрытые сообщества',
    'Private (Invisible)' => 'Закрытое сообщество (скрытое ото всех, кроме его участников)',
    'Public' => 'Открытые сообщества',
    'Public (Members & Guests)' => 'Публичное (Участники и Гости)',
    'Public (Members only)' => 'Публичное (только Участники)',
    'Public (Registered users only)' => 'Видимо для Пользователей (только для зарегистрированных)',
    'Request Message' => 'Запрашиваемое сообщение',
    'Role' => 'Роль',
    'Search...' => 'Поиск...',
    'See all' => 'Посмотреть все',
    'Select all registered users' => 'Выбрать всех зарегистрированных пользователей',
    'Send' => 'Отправить',
    'Send the link via email' => 'Отправьте ссылку по электронной почте',
    'Settings' => 'Настройки',
    'Settings could not be saved!' => 'Настройки не удалось сохранить!',
    'Show all' => 'Показать всех',
    'Show as List' => 'Показать как список',
    'Shown on About Page.' => 'Отображается на странице «Информация».',
    'Sorry, you are not allowed to leave this space!' => 'Извините, Вам не разрешено покинуть это сообщество',
    'Sorting' => 'Сортировка',
    'Space' => 'Сообщество',
    'Space Name' => 'Название сообщества',
    'Space Visibility' => 'Видимость сообщества',
    'Space directory' => 'Директория сообщества',
    'Space is invisible!' => 'Сообщество скрыто!',
    'Spaces' => 'Сообщества',
    'Status' => 'Статус',
    'Stream' => 'Активность',
    'Tags' => 'Теги',
    'The default homepage for members of this Space' => 'Домашняя страница по умолчанию для участников этого сообщества.',
    'The default homepage for non-members and guests visiting this Space' => 'Домашняя страница по умолчанию для лиц, не являющихся участниками, и гостей, посещающих это сообщество.',
    'The secure link has been copied in your clipboard!' => 'Защищенная ссылка скопирована в буфер обмена!',
    'There is no pending invite!' => 'Нет ожидающих приглашений!',
    'This action is only available for workspace members!' => 'Это действие доступно только для участников этого сообщества!',
    'This user is already a member of this space.' => 'Этот пользователь уже является участником этого сообщества.',
    'This user is not a member of this space.' => 'Этот пользователь не является участником этого сообщества.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Чтобы пригласить пользователей в это сообщество, введите их имена ниже, чтобы найти и выбрать их.',
    'Try other keywords or remove filters.' => 'Попробуйте другие ключевые слова или удалите фильтры.',
    'Updated At' => 'Обновлено в',
    'Updated By' => 'Обновлено',
    'Updated by' => 'Обновлено',
    'User \'{username}\' is already a member of this space!' => 'Пользователь \'{username}\' уже является участником этого сообщества!',
    'User invitations have been added to the queue' => 'Приглашения на вступления для пользователей добавлены',
    'User memberships have been added to the queue' => 'Пользователи приглашены для вступления',
    'User not found!' => 'Пользователь не найден!',
    'Users' => 'Пользователи',
    'Users has been invited.' => 'Пользователи были приглашены.',
    'Visibility' => 'Видимость сообщества',
    'Visible for all (members and guests)' => 'Видимо для всех (для Участников и Гостей)',
    'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => 'Предупреждение. Если вы измените настройки видимости сообщества с общедоступного на частное, весь контент в этом сообществе, включая публикации, комментарии, вложения и т. д., также станет частным. Это означает, что лица, не являющиеся участниками, больше не смогут видеть, получать доступ или взаимодействовать с каким-либо контентом в этом Сообществе.',
    'Would you like to end your membership in Space {spaceName}?' => 'Хотите прекратить свое членство в Сообществе {spaceName}?',
    'Would you like to unfollow Space {spaceName}?' => 'Хотите отписаться от Сообщества {spaceName}?',
    'Would you like to unfollow {userName}?' => 'Хотите отписаться от пользователя {userName}?',
    'Would you like to withdraw your request to join Space {spaceName}?' => 'Хотите отозвать свой запрос на вступление в Сообщество {spaceName}?',
    'You are not allowed to join this space!' => 'Вы не можете присоединиться к этому сообществу!',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Вы также можете пригласить по электронной почте внешних пользователей, которые сейчас не зарегистрированы. Просто добавьте их адреса электронной почты через запятую.',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'Вы можете пригласить внешних пользователей, которые в данный момент не зарегистрированы, по ссылке. Все, что вам нужно сделать, это поделиться с ними этой безопасной ссылкой.',
    'You cannot create private visible spaces!' => 'Вы не можете создавать закрытые сообщества!',
    'You cannot create public visible spaces!' => 'Вы не можете создавать открытые (публичные) сообщества!',
    'You need to login to view contents of this space!' => 'Вы должны войти/зарегистрироваться, чтобы просматривать содержимое этого сообщества!',
    'Your Message' => 'Сообщение',
    'Your request was successfully submitted to the space administrators.' => 'Ваша заявка на вступление была успешно отправлена администратору сообщества.',
    '{count} members' => '{count} участников',
    '{email} is not valid!' => '{email} некорректный!',
    'Add as Default Space for new users' => '',
    'Default Stream Sort' => '',
    'Stream Sort' => '',
];
